"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.cypressBrowserPermissionsPlugin = exports.modifyAndTransformPluginEnv = exports.onBeforeBrowserLaunch = void 0;
const lodash_1 = require("lodash");
const types_1 = require("./types");
const helpers_1 = require("./helpers");
const constants_1 = require("./constants");
function resetBrowserPermissions(browser, launchOptions) {
    const path = helpers_1.getBrowserLaunchOptionsPermissionsContainerPath(browser.family);
    if (path) {
        lodash_1.unset(launchOptions, path);
    }
}
function onBeforeBrowserLaunch(config) {
    return (browser, launchOptions) => {
        const requestedPermissions = helpers_1.getBrowserPermissionsFromEnv(config.env);
        resetBrowserPermissions(browser, launchOptions);
        lodash_1.forOwn(requestedPermissions, (value, permission) => {
            const path = helpers_1.getBrowserLaunchOptionsPermissionsPath(browser.family, permission);
            if (path) {
                lodash_1.set(launchOptions, path, value);
                console.info(`[browserPermissions] permission '${permission}' => '${types_1.PermissionState[value]}'`);
            }
        });
        return launchOptions;
    };
}
exports.onBeforeBrowserLaunch = onBeforeBrowserLaunch;
function modifyAndTransformPluginEnv({ env }) {
    const envOverrides = lodash_1.pickBy(env, (_, key) => lodash_1.camelCase(key).startsWith(constants_1.PLUGIN_ENV_VAR) && lodash_1.camelCase(key) !== constants_1.PLUGIN_ENV_VAR);
    const permissionOverrides = lodash_1.mapKeys(envOverrides, (_, key) => {
        return lodash_1.camelCase(lodash_1.camelCase(key).replace(constants_1.PLUGIN_ENV_VAR, ''));
    });
    env.browserPermissions = {
        ...env.browserPermissions,
        ...permissionOverrides,
    };
    lodash_1.keys(envOverrides).forEach((key) => lodash_1.unset(env, key));
}
exports.modifyAndTransformPluginEnv = modifyAndTransformPluginEnv;
function cypressBrowserPermissionsPlugin(on, config) {
    modifyAndTransformPluginEnv(config);
    on('before:browser:launch', onBeforeBrowserLaunch(config));
    return config;
}
exports.cypressBrowserPermissionsPlugin = cypressBrowserPermissionsPlugin;
//# sourceMappingURL=plugin.js.map